==> mysql-community-8.0-mroonga_15.22.orig.tar.gz: mysql-community-8.0-mroonga-15.22/doc/source/news/15.md <==
# News - 15 series

(release-15-22)=
## Release 15.22 - 2025-12-10

### Added new support for MariaDB 11.8 in the following OS.

* Windows

### Added support for MySQL 8.0.44-0ubuntu0.22.04.2 on Ubuntu

This is the latest MySQL 8.0 release.

(release-15-21)=
## Release 15.21 - 2025-12-04

### Added new support for MariaDB 11.8 in the following OS.

* AlmaLinux 8.
* AlmaLinux 9.
* Debian 13 (trixie).

### Added support for MySQL Community Server 8.0.44 in the following OS.

* AlmaLinux 8, 9
* Debian 12 (bookworm)
* Ubuntu 22.04 (jammy), 24.04 (noble)

8.0.44 is the latest MySQL Community Server 8.0 release.

### Added support for MySQL Community Server 8.4.7 in the following OS.

* AlmaLinux 8, 9, and 10
* Debian 12 (bookworm)
* Ubuntu 22.04 (jammy), 24.04 (noble)

8.4.7 is the latest MySQL Community Server 8.4 release.

### Added support for MySQL Community Server minimal 8.0.44 in the following OS.

* AlmaLinux 9

8.0.44 is the latest MySQL Community Server minimal 8.0 release.

### Added support for MySQL Community Server minimal 8.4.7 in the following OS.

* AlmaLinux 9

8.4.7 is the latest MySQL Community Server minimal 8.4 release.

### Added support for MariaDB 10.6.24 in the following OS.

* AlmaLinux 8, 9

10.6.24 is the latest MariaDB 10.6 release.

### Added support for MariaDB 10.11.15 in the following OS.

* AlmaLinux 8, 9

10.11.15 is the latest MariaDB 10.11 release.

### Added support for MariaDB 11.4.9 in the following OS.

* AlmaLinux 8, 9

11.4.9 is the latest MariaDB 11.4 release.

### Added support for Percona Server for MySQL 8.0.44-35 in the following OS.

* AlmaLinux 8, 9

8.0.44-35 is the latest Percona Server for MySQL 8.0 release.

(release-15-17)=
## Release 15.17 - 2025-09-29

### Improvements

### Added support for MariaDB 10.11.14 on Debian

This is the latest MariaDB 10.11 release.

### Added support for MySQL 8.0.43 on Ubuntu

This is the latest MySQL 8.0.43 release.

(release-15-16)=
## Release 15.16 - 2025-09-03

### Improvements

#### Added support for MySQL Community 8.0.43 on AlmaLinux, Debian, and Ubuntu

This is the latest MySQL Community 8.0 release.

#### Added support for MySQL Community 8.4.6 on AlmaLinux, Debian, and Ubuntu

This is the latest MySQL Community 8.4 release.

### Dropped support for MariaDB 10.5

Support for MariaDB 10.5 has been dropped because it has reached EOL.

### Added documentation for limitations of the primary key

[[MDEV-37317]( https://jira.mariadb.org/browse/MDEV-37317 )][Reported by Elena Stepanova]

We added the following description in documentation of {doc}`/reference/limitations`:

- "Empty data (0 byte data) is not allowed in the primary key"

### Thanks

Elena Stepanova

(release-15-11)=
## Release 15.11 - 2025-06-06

### Improvements

#### Added support for MariaDB 10.6.22 and 10.11.13 on Ubuntu

These are the latest MariaDB release.

#### Added support for MariaDB 10.11.13 and 11.4.7 on AlmaLinux

These are the latest MariaDB release.

(release-15-10)=
## Release 15.10 - 2025-05-14

### Improvements

#### Added support for MySQL 8.0.42 on Ubuntu

This is the latest MySQL release.

#### Added support for MariaDB 10.5.29 and 10.6.22

These are the latest MariaDB release.

(release-15-07)=
## Release 15.07 - 2025-04-23

### Improvements

#### Added support for `utf8mb4_uca1400_*` collations

Now, Mroonga is integrated with the latest groonga‑normalizer‑mysql 1.2.6, so
Mroonga supports the following `utf8mb4_uca1400_*` collations.

- `utf8mb4_uca1400_ai_ci`
- `utf8mb4_uca1400_ai_cs`
- `utf8mb4_uca1400_as_ci`
- `utf8mb4_uca1400_as_cs`

#### Added support for MySQL Community 8.0.42

This is the latest MySQL Community release.

(release-15-05)=
## Release 15.05 - 2025-04-08

### Improvements

#### Added support for MariaDB 10.6.21 and 10.11.11

They are the latest MariaDB releases.

(release-15-04)=
## Release 15.04 - 2025-03-29

### Improvements

#### {doc}`/install/ubuntu`: Dropped support for Ubuntu 20.04

It will reach EOL on 2025-04.

#### {doc}`/install/almalinux`: Added support for Percona Server 8.4

It's available only for AlmaLinux 9 and Red Hat Enterprise Linux 9
compatible distributions.

#### Added support for MariaDB 11.8 partially

MariaDB 11.8 isn't GA yet but Mroonga is buildable with MariaDB 11.8.

MariaDB 11.8 uses `utf8mb4_uca1400_*` collations by
default. groonga-normalizer-mysql 1.2.6 has a `utf8mb4_uca1400_*`
compatible normalizer but it's not integrated with Mroonga. It'll be
implemented in the next release!

#### {doc}`/install/windows`: Changed to use Visual Studio 2022 from 2019

Our pre-built packages for old releases were built with Visual Studio
2019 but we use Visual Studio 2022 from this release. This will not be
affected to users.

(release-15-00)=
## Release 15.00 - 2025-02-09

This is our annual major release! This release doesn't have any
backward incompatible changes! So you can upgrade Mroonga without
migrating your existing databases. You can still use your existing
databases as-is.

### Improvements

#### {ref}`server-variable-mroonga-n-workers`: Added support for parallel execution

[GH-877](https://github.com/mroonga/mroonga/issues/877)

You can set concurrency in Groonga by
{ref}`server-variable-mroonga-n-workers`. Some operations such as
`CREATE INDEX` refer this server variable. You can use this to
improve performance by using multiple CPU cores.

In general, you should set this in `my.cnf` not `SET`. Because this
doesn't change concurrency in the current session (at least for
now). If you want to change this by `SET`, you need to set by `SET
GLOBAL` and re-connect to MySQL.

#### MariaDB: Added support for MariaDB 10.5.28, 10.6.21, 10.11.11 and 11.4.5

You can use Mroonga with the latest MariaDB releases.

### Fixes

#### {doc}`/tutorial/wrapper`: Fixed a bug that wrapped engine's index information may not be used correctly

[GH-634](https://github.com/mroonga/mroonga/issues/634)

If wrapped engine's index information isn't used correctly, MariaDB
may not be able to use suitable index. It may cause a poor performance
query execution.

==> mysql-community-8.4-mroonga_15.25.orig.tar.gz: mysql-community-8.4-mroonga-15.25/doc/source/news/15.md <==
# News - 15 series

(release-15-25)=
## Release 15.25 - 2026-02-06

### Improvements

### Added new support for the following MariaDB on AlmaLinux 10

* MariaDB 10.11, 11.4, and 11.8

### Added support for MySQL 8.0.45-0ubuntu0.24.04.1 on Ubuntu 24.04

This is the latest MySQL Community Server 8.0.

### Added support for MySQL 8.0.45-0ubuntu0.22.04.1 on Ubuntu 22.04

This is the latest MySQL Community Server 8.0.

### Added support for MariaDB 11.8.6 in the following OS

* AlmaLinux 8, 9

This is the latest MariaDB 11.8 release.

### Added support for MariaDB 11.4.10 in the following OS

* AlmaLinux 8, 9

This is the latest MariaDB 11.4 release.

### Added support for MariaDB 10.11.16 in the following OS

* AlmaLinux 8, 9

This is the latest MariaDB 10.11 release.

### Added support for MariaDB 10.6.25 in the following OS

* AlmaLinux 8, 9

This is the latest MariaDB 10.6 release.

### Fixes

### Fixed a crash bug that occurred when `mroonga_default_tokenizer` was set to `NULL`

[[GH-1041]( https://github.com/mroonga/mroonga/pull/1041 )][Patched by Hadeer Ramadan]

For example, this bug occurred when `mroonga_default_tokenizer` was set to `NULL`, as shown below.

```sql
SET GLOBAL mroonga_default_tokenizer = NULL;
```

### Thanks

* Hadeer Ramadan

(release-15-23)=
## Release 15.23 - 2026-01-27

### Improvements

### Added support for MySQL Community Server 8.0.45 in the following OS.

* AlmaLinux 8, 9
* Debian 12 (bookworm)
* Ubuntu 22.04 (jammy), 24.04 (noble)

8.0.45 is the latest MySQL Community Server 8.0 release.

### Added support for MySQL Community Server 8.4.8 in the following OS.

* AlmaLinux 8, 9, and 10
* Debian 12 (bookworm), 13 (trixie)
* Ubuntu 22.04 (jammy), 24.04 (noble)

8.4.8 is the latest MySQL Community Server 8.4 release.

### Added support for MySQL Community Server minimal 8.0.45 in the following OS.

* AlmaLinux 9

8.0.45 is the latest MySQL Community Server minimal 8.0 release.

### Added support for MySQL Community Server minimal 8.4.8 in the following OS.

* AlmaLinux 9

8.4.8 is the latest MySQL Community Server minimal 8.4 release.

### Added support for MariaDB 10.11.14-0ubuntu0.24.04.1 on Ubuntu 24.04

This is the latest MariaDB 10.11 release.

### Added support for MariaDB 10.6.23-0ubuntu0.22.04.1 on Ubuntu 22.04

This is the latest MariaDB 10.6 release.

(release-15-22)=
## Release 15.22 - 2025-12-10

### Improvements

### Added new support for MariaDB 11.8 in the following OS.

* Windows

### Added support for MySQL 8.0.44-0ubuntu0.22.04.2 on Ubuntu

This is the latest MySQL 8.0 release.

(release-15-21)=
## Release 15.21 - 2025-12-04

### Improvements

### Added new support for MariaDB 11.8 in the following OS.

* AlmaLinux 8.
* AlmaLinux 9.
* Debian 13 (trixie).

### Added support for MySQL Community Server 8.0.44 in the following OS.

* AlmaLinux 8, 9
* Debian 12 (bookworm)
* Ubuntu 22.04 (jammy), 24.04 (noble)

8.0.44 is the latest MySQL Community Server 8.0 release.

### Added support for MySQL Community Server 8.4.7 in the following OS.

* AlmaLinux 8, 9, and 10
* Debian 12 (bookworm)
* Ubuntu 22.04 (jammy), 24.04 (noble)

8.4.7 is the latest MySQL Community Server 8.4 release.

### Added support for MySQL Community Server minimal 8.0.44 in the following OS.

* AlmaLinux 9

8.0.44 is the latest MySQL Community Server minimal 8.0 release.

### Added support for MySQL Community Server minimal 8.4.7 in the following OS.

* AlmaLinux 9

8.4.7 is the latest MySQL Community Server minimal 8.4 release.

### Added support for MariaDB 10.6.24 in the following OS.

* AlmaLinux 8, 9

10.6.24 is the latest MariaDB 10.6 release.

### Added support for MariaDB 10.11.15 in the following OS.

* AlmaLinux 8, 9

10.11.15 is the latest MariaDB 10.11 release.

### Added support for MariaDB 11.4.9 in the following OS.

* AlmaLinux 8, 9

11.4.9 is the latest MariaDB 11.4 release.

### Added support for Percona Server for MySQL 8.0.44-35 in the following OS.

* AlmaLinux 8, 9

8.0.44-35 is the latest Percona Server for MySQL 8.0 release.

(release-15-17)=
## Release 15.17 - 2025-09-29

### Improvements

### Added support for MariaDB 10.11.14 on Debian

This is the latest MariaDB 10.11 release.

### Added support for MySQL 8.0.43 on Ubuntu

This is the latest MySQL 8.0.43 release.

(release-15-16)=
## Release 15.16 - 2025-09-03

### Improvements

#### Added support for MySQL Community 8.0.43 on AlmaLinux, Debian, and Ubuntu

This is the latest MySQL Community 8.0 release.

#### Added support for MySQL Community 8.4.6 on AlmaLinux, Debian, and Ubuntu

This is the latest MySQL Community 8.4 release.

### Dropped support for MariaDB 10.5

Support for MariaDB 10.5 has been dropped because it has reached EOL.

### Added documentation for limitations of the primary key

[[MDEV-37317]( https://jira.mariadb.org/browse/MDEV-37317 )][Reported by Elena Stepanova]

We added the following description in documentation of {doc}`/reference/limitations`:

- "Empty data (0 byte data) is not allowed in the primary key"

### Thanks

Elena Stepanova

(release-15-11)=
## Release 15.11 - 2025-06-06

### Improvements

#### Added support for MariaDB 10.6.22 and 10.11.13 on Ubuntu

These are the latest MariaDB release.

#### Added support for MariaDB 10.11.13 and 11.4.7 on AlmaLinux

These are the latest MariaDB release.

(release-15-10)=
## Release 15.10 - 2025-05-14

### Improvements

#### Added support for MySQL 8.0.42 on Ubuntu

This is the latest MySQL release.

#### Added support for MariaDB 10.5.29 and 10.6.22

These are the latest MariaDB release.

(release-15-07)=
## Release 15.07 - 2025-04-23

### Improvements

#### Added support for `utf8mb4_uca1400_*` collations

Now, Mroonga is integrated with the latest groonga‑normalizer‑mysql 1.2.6, so
Mroonga supports the following `utf8mb4_uca1400_*` collations.

- `utf8mb4_uca1400_ai_ci`
- `utf8mb4_uca1400_ai_cs`
- `utf8mb4_uca1400_as_ci`
- `utf8mb4_uca1400_as_cs`

#### Added support for MySQL Community 8.0.42

This is the latest MySQL Community release.

(release-15-05)=
## Release 15.05 - 2025-04-08

### Improvements

#### Added support for MariaDB 10.6.21 and 10.11.11

They are the latest MariaDB releases.

(release-15-04)=
## Release 15.04 - 2025-03-29

### Improvements

#### {doc}`/install/ubuntu`: Dropped support for Ubuntu 20.04

It will reach EOL on 2025-04.

#### {doc}`/install/almalinux`: Added support for Percona Server 8.4

It's available only for AlmaLinux 9 and Red Hat Enterprise Linux 9
compatible distributions.

#### Added support for MariaDB 11.8 partially

MariaDB 11.8 isn't GA yet but Mroonga is buildable with MariaDB 11.8.

MariaDB 11.8 uses `utf8mb4_uca1400_*` collations by
default. groonga-normalizer-mysql 1.2.6 has a `utf8mb4_uca1400_*`
compatible normalizer but it's not integrated with Mroonga. It'll be
implemented in the next release!

#### {doc}`/install/windows`: Changed to use Visual Studio 2022 from 2019

Our pre-built packages for old releases were built with Visual Studio
2019 but we use Visual Studio 2022 from this release. This will not be
affected to users.

(release-15-00)=
## Release 15.00 - 2025-02-09

This is our annual major release! This release doesn't have any
backward incompatible changes! So you can upgrade Mroonga without
migrating your existing databases. You can still use your existing
databases as-is.

### Improvements

#### {ref}`server-variable-mroonga-n-workers`: Added support for parallel execution

[GH-877](https://github.com/mroonga/mroonga/issues/877)

You can set concurrency in Groonga by
{ref}`server-variable-mroonga-n-workers`. Some operations such as
`CREATE INDEX` refer this server variable. You can use this to
improve performance by using multiple CPU cores.

In general, you should set this in `my.cnf` not `SET`. Because this
doesn't change concurrency in the current session (at least for
now). If you want to change this by `SET`, you need to set by `SET
GLOBAL` and re-connect to MySQL.

#### MariaDB: Added support for MariaDB 10.5.28, 10.6.21, 10.11.11 and 11.4.5

You can use Mroonga with the latest MariaDB releases.

### Fixes

#### {doc}`/tutorial/wrapper`: Fixed a bug that wrapped engine's index information may not be used correctly

[GH-634](https://github.com/mroonga/mroonga/issues/634)

If wrapped engine's index information isn't used correctly, MariaDB
may not be able to use suitable index. It may cause a poor performance
query execution.
